# Instructions

#### This is our test project.

#### Please install this package
```
pip install functions-by-nomadstalker
```


#### You can also install older packages
```
pip install functions_by_nomadstalker==VERSION_NUMBER
```